CoreEvent

Enum CoreEvent 

#[non_exhaustive]
pub enum CoreEvent { SpeakingStateUpdate, VoiceTick, RtpPacket, RtcpPacket, ClientDisconnect, DriverConnect, DriverReconnect, DriverDisconnect, }
Voice core events occur on receipt of voice packets and telemetry.

Core events persist while the action in EventData returns None.

Events from other users

Songbird can observe when a user speaks for the first time (SpeakingStateUpdate), when a client leaves the session (ClientDisconnect).

When the "receive" feature is enabled, songbird can also handle voice packets (RtpPacket), decode and track speaking users (VoiceTick), and handle telemetry data (RtcpPacket). The format of voice packets is described by VoiceData.

To detect when a user connects, you must correlate gateway (e.g., VoiceStateUpdate) events from the main part of your bot.

To obtain a user’s SSRC, you must use SpeakingStateUpdate events.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SpeakingStateUpdate

Speaking state update from the WS gateway, typically describing how another voice user is transmitting audio data. Clients must send at least one such packet to allow SSRC/UserID matching.

Fired on receipt of a speaking state update from another host.

Note: this will fire when a user starts speaking for the first time, or changes their capabilities.



VoiceTick

Fires every 20ms, containing the scheduled voice packet and decoded audio data for each live user.



RtpPacket

Fires on receipt of a voice packet from another stream in the voice call.

As RTP packets do not map to Discord’s notion of users, SSRCs must be mapped back using the user IDs seen through client connection, disconnection, or speaking state update.



RtcpPacket

Fires on receipt of an RTCP packet, containing various call stats such as latency reports.



ClientDisconnect

Fires whenever a user disconnects from the same stream as the bot.



DriverConnect

Fires when this driver successfully connects to a voice channel.



DriverReconnect

Fires when this driver successfully reconnects after a network error.



DriverDisconnect

Fires when this driver fails to connect to, or drops from, a voice channel.