pub struct EventStore { /* private fields */ }Expand description
Storage for EventData, designed to be used for both local and global contexts.
Timed events are stored in a binary heap for fast selection, and have custom Eq,
Ord, etc. implementations to support (only) this.
Implementations
Sourceimpl EventStore
impl EventStore
Sourcepub fn new_local() -> Self
pub fn new_local() -> Self
Creates a new event store to be used within a Track.
This is usually automatically installed by the driver once a track has been registered.
Sourcepub fn add_event(&mut self, evt: EventData, now: Duration)
pub fn add_event(&mut self, evt: EventData, now: Duration)
Add an event to this store.
Updates evt according to EventData::compute_activation.